//
//  AGUpdate.h
//  AraeliumUpdate
//
//  Created by Seth Willits on 8/14/12.
//  Copyright (c) 2012 Araelium Group. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "AGUpdateItem.h"


typedef void (^AGUpdateDownloadProgressHandler)(double progress);
typedef void (^AGUpdateDownloadCompletionHandler)(NSError * error);

typedef void (^AGUpdateInstallErrorHandler)(NSError * error);


enum {
	AGUpdateStatusInfoOnly = 0,
	AGUpdateStatusDownloading,
	AGUpdateStatusDownloaded,
	AGUpdateStatusUnarchiving,
	AGUpdateStatusUnarchived
};



@interface AGUpdate : NSObject <AGUpdateItem>
{
	NSString * title;
	NSString * dateString;
	NSString * itemDescription;
	NSString * extra;
	NSURL * releaseNotesURL;
	NSString * minimumSystemVersion;
	NSString * maximumSystemVersion;
	NSURL * fileURL;
	NSURL * linkURL;
	NSString * version;
	NSString * displayVersion;
	NSDictionary * propertiesDictionary;
	
	AGUpdateDownloadProgressHandler mDownloadProgressHandler;
	AGUpdateDownloadCompletionHandler mDownloadCompletionHandler;
	NSURLDownload * mDownload;
	BOOL mIsDownloaded;
	BOOL mIsDownloading;
	NSString * mDownloadPath;
	double mDownloadProgress;
	NSUInteger mDownloadReceived;
	uint64_t mDownloadSize;
	
	AGUpdateInstallErrorHandler mInstallErrorHandler;
	BOOL mIsInstalling;
	BOOL mIsInstalled;
}


@property (readonly, copy) NSString * title;
@property (readonly, copy) NSString * version;
@property (readonly, copy) NSString * displayVersion;
@property (readonly, copy) NSString * itemDescription;
@property (readonly, copy) NSString * extra;
@property (readonly, copy) NSURL * releaseNotesURL;
@property (readonly, copy) NSURL * fileURL;
@property (readonly, copy) NSURL * linkURL;

- (void)ignore;
- (void)launch;


- (void)downloadWithProgress:(AGUpdateDownloadProgressHandler)progressHandler completion:(AGUpdateDownloadCompletionHandler)completionHandler;
- (void)cancelDownload;

@property (readonly) BOOL canBeDownloaded; //! Has a fileURL
@property (readonly) BOOL isDownloading;
@property (readonly) BOOL isDownloaded;
@property (readonly, copy) NSString * downloadPath;
@property (readonly) double downloadProgress;
@property (readonly) uint64_t downloadSize;


- (void)installWithErrorHandler:(AGUpdateInstallErrorHandler)errorHandler;
@property (readonly) BOOL isInstalling;
@property (readonly) BOOL isInstalled;

@end
